@@ -7,5 +7,5 @@ from .false_positive_rate import FalsePositiveRate  # noqa
 from .negative_predictive_value import NegativePredictiveValue  # noqa
 from .precision import Precision  # noqa
 from .recall import Recall  # noqa
-from .accuracy import Accuracy  # noqa
+from .binary_accuracy import BinaryAccuracy  # noqa
 from .utils import make_classification_metric  # noqa
