@@ -1,4 +1,5 @@
 from .utils import select_examples  # noqa
 from .memory_samplers import MultiShotMemorySampler  # noqa
 from .memory_samplers import SingleShotMemorySampler  # noqa
-from .tddataset_sampler import TFRecordDatasetSampler  # noqa
+from .tfrecords_samplers import TFRecordDatasetSampler  # noqa
+from .tfdataset_samplers import TFDatasetMultiShotMemorySampler  # noqa
