@@ -1,6 +1,6 @@
 import random
 from collections import defaultdict
-from typing import Optional, Tuple, Sequence
+from typing import Optional, Tuple, TypeVar, Sequence
 
 import tensorflow as tf
 from tensorflow_similarity.types import FloatTensor, IntTensor, Tensor
@@ -9,6 +9,8 @@ from tqdm.auto import tqdm
 from .samplers import Augmenter, Sampler
 from .utils import select_examples
 
+T = TypeVar('T', FloatTensor, IntTensor)
+
 
 class MultiShotMemorySampler(Sampler):
     # FIXME: typing x, y is hard.
@@ -100,8 +102,8 @@ class MultiShotMemorySampler(Sampler):
                                num_examples_per_class=total_examples_per_class)
 
         # assign after potential selection
-        self.x = x
-        self.y = y
+        self._x = x
+        self._y = y
 
         # we need to reindex here  as the numbers of samples might have
         # changed due to the filtering
@@ -113,9 +115,10 @@ class MultiShotMemorySampler(Sampler):
             cl = cls[idx]
             self.index_per_class[cl].append(idx)
 
-    def get_examples(self, batch_id: int, num_classes: int,
+    def get_examples(self,
+                     batch_id: int,
+                     num_classes: int,
                      examples_per_class: int) -> Tuple[Tensor, Tensor]:
-
         # select class at ramdom
         class_list = random.sample(self.class_list, k=num_classes)
 
@@ -126,11 +129,56 @@ class MultiShotMemorySampler(Sampler):
             idxs.extend(random.choices(class_idxs, k=examples_per_class))
 
         random.shuffle(idxs)
-        batch_x = tf.gather(self.x, idxs[:self.batch_size])
-        batch_y = tf.gather(self.y, idxs[:self.batch_size])
+        idxs_slice = tf.constant(idxs[:self.batch_size])
+
+        with tf.device("/cpu:0"):
+            batch_x = tf.gather(self._x, indices=idxs_slice)
+            batch_y = tf.gather(self._y, indices=idxs_slice)
 
         return batch_x, batch_y
 
+    def get_slice(self,
+                  begin: int = 0,
+                  size: int = -1) -> Tuple[FloatTensor, IntTensor]:
+        """Extracts a slice over both the x and y tensors.
+
+        This method extracts a slice of size `size` over the first dimension of
+        both the x and y tensors starting at the index specified by `begin`.
+
+        The value of `begin + size` must be less than `self.num_examples`.
+
+        Args:
+            begin: The starting index.
+            size: The size of the slice.
+
+        Returns:
+            A Tuple of FloatTensor and IntTensor
+        """
+        slice_x: FloatTensor = self._get_slice(self._x, begin, size)
+        slice_y: IntTensor = self._get_slice(self._y, begin, size)
+
+        return slice_x, slice_y
+
+    def _get_slice(self,
+                   input_: T,
+                   begin: int,
+                   size: int) -> T:
+        b = [0] * len(tf.shape(input_))
+        b[0] = begin
+        s = [-1] * len(tf.shape(input_))
+        s[0] = size
+
+        slice_: T = tf.slice(input_, b, s)
+        return slice_
+
+    @property
+    def num_examples(self) -> int:
+        return len(self._x)
+
+    @property
+    def example_shape(self):
+        return self._x[0].shape
+
 
 class SingleShotMemorySampler(Sampler):
     def __init__(self,
