@@ -97,7 +97,6 @@ class Sampler(Sequence, metaclass=abc.ABCMeta):
         Returns:
             x, y: batch of examples made of `num_classes` * `example_per_class`
         """
-        raise NotImplementedError('must be implemented by subclass')
 
     # [Shared mechanics]
     def __len__(self) -> int:
@@ -112,7 +111,7 @@ class Sampler(Sequence, metaclass=abc.ABCMeta):
         #     self.scheduler(self.epoch)
 
         self.epoch += 1
-        if self.epoch >= self.warmup and self.is_warmup > 0:
+        if self.is_warmup and (self.epoch >= self.warmup):
             print("Warmup complete")
             self.is_warmup = False
 
