@@ -1,9 +1,10 @@
-from tqdm.auto import tqdm
 from collections import defaultdict
 import random
 from typing import Sequence, Tuple
 
+from tqdm.auto import tqdm
 import tensorflow as tf
+
 from tensorflow_similarity.types import IntTensor, FloatTensor
 
 
@@ -63,8 +64,10 @@ def select_examples(x: FloatTensor,
             idxs.extend(class_idxs)
 
     random.shuffle(idxs)
+    idxs = tf.constant(idxs)
+
     with tf.device("/cpu:0"):
-        batch_x = tf.gather(x, idxs)
-        batch_y = tf.gather(y, idxs)
+        batch_x = tf.gather(x, indices=idxs)
+        batch_y = tf.gather(y, indices=idxs)
 
     return batch_x, batch_y
